@@ -836,6 +836,15 @@ class KongEks(
     def telemetry_dns(self, value: builtins.str) -> None:
         jsii.set(self, "telemetryDns", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="prometheusEndpoint")
+    def prometheus_endpoint(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "prometheusEndpoint"))
+
+    @prometheus_endpoint.setter
+    def prometheus_endpoint(self, value: typing.Optional[builtins.str]) -> None:
+        jsii.set(self, "prometheusEndpoint", value)
+
 
 @jsii.data_type(
     jsii_type="kong-control-plane.KongFeatureProps",
