@@ -13,7 +13,10 @@ import constructs._jsii
 import kong_core._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "kong-control-plane", "2.0.9", __name__[0:-6], "kong-control-plane@2.0.9.jsii.tgz"
+    "kong-control-plane",
+    "2.0.10",
+    __name__[0:-6],
+    "kong-control-plane@2.0.10.jsii.tgz",
 )
 
 __all__ = [
